import greenfoot.Greenfoot;
import greenfoot.MouseInfo;
import greenfoot.World;

import java.util.ArrayList;

/**
 * Representation of the smog world
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Picture extends World {

	public static final int COLS = 20;
	public static final int ROWS = 15;
	public static final int CELLSIZE = 30;
	public static final int NOOF_PICS = 11;

	private Smog[][] smog;
	private int startPollution;
	private NextButton next;
	private int picNumber;

	private ArrayList<Integer> picNumbers;

	public Picture() {
		super(Picture.COLS, Picture.ROWS, Picture.CELLSIZE);
		this.picNumbers = new ArrayList<Integer>(Picture.NOOF_PICS);
		this.picNumber = Greenfoot.getRandomNumber(Picture.NOOF_PICS);
		this.setBackground("picture-" + this.picNumber + ".jpg");
		this.picNumbers.add(this.picNumber);
		this.smog = new Smog[Picture.COLS][Picture.ROWS];
		for (int c = 0; c < Picture.COLS; c++) {
			for (int r = 0; r < Picture.ROWS; r++) {
				this.smog[c][r] = new Smog();
				this.addObject(this.smog[c][r], c, r);
			}
		}
	}

	public void started() {
	    Greenfoot.setSpeed(45);
		this.removeObjects(this.getObjects(NextButton.class));
		for (int c = 0; c < Picture.COLS; c++) {
			for (int r = 0; r < Picture.ROWS; r++) {
				this.smog[c][r].init();
			}
		}
		this.startPollution = this.getPollution();
		this.next = null;
	}

	public void act() {
		if (this.next == null) {
			int currentPollution = this.getPollution();
			if (currentPollution <= 8 * this.startPollution / 10) {
				this.next = new NextButton();
				this.addObject(this.next, Picture.COLS - 2, Picture.ROWS - 2);
			}
		}
		if (Greenfoot.mousePressed(null) || Greenfoot.mouseDragged(null)) {
			MouseInfo mouse = Greenfoot.getMouseInfo();
			int x = mouse.getX();
			int y = mouse.getY();
			if (x >= 0 && x < Picture.COLS && y >= 0 && y < Picture.ROWS) {
				this.smog[mouse.getX()][mouse.getY()].clean();
			}
		}
	}

	public void nextPicture() {
		this.started();
		this.setBackground("picture-" + this.getPicNumber() + ".jpg");
	}

	int getPollution() {
		int pollution = 0;
		for (int c = 0; c < Picture.COLS; c++) {
			for (int r = 0; r < Picture.ROWS; r++) {
				pollution += this.smog[c][r].getPollution();
			}
		}
		return pollution;
	}

	int getPicNumber() {
		if (this.picNumbers.size() == Picture.NOOF_PICS) {
			this.picNumbers.clear();
		}
		int no = Greenfoot.getRandomNumber(Picture.NOOF_PICS);
		while (this.picNumbers.contains(no)) {
			no = Greenfoot.getRandomNumber(Picture.NOOF_PICS);
		}
		this.picNumber = no;
		this.picNumbers.add(this.picNumber);
		return this.picNumber;
	}

}
